@@ -1,12 +1,10 @@
 package SPVM::IO::Socket;
 
-our $VERSION = '0.01';
-
 1;
 
 =head1 NAME
 
-SPVM::IO::Socket - Interface of Socket
+SPVM::IO::Socket - Socket
 
 =head1 SYNOPSYS
   
